==> mastapy-14.1.0rc1-py3-none-any.whl: mastapy/_private/_internal/implicit/overridable/diameter_series.py <==
"""Implementations of 'Overridable' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal import mixins
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.bearings.bearing_designs.rolling import _2216

_OVERRIDABLE = python_net_import("SMT.MastaAPI.Utility.Property", "Overridable")

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="Overridable_DiameterSeries")


__docformat__ = "restructuredtext en"
__all__ = ("Overridable_DiameterSeries",)


class Overridable_DiameterSeries(mixins.OverridableMixin, Enum):
    """Overridable_DiameterSeries

    A specific implementation of 'Overridable' for 'DiameterSeries' types.
    """

    __qualname__ = "DiameterSeries"

    @classmethod
    def wrapper_type(cls: "Type[Overridable_DiameterSeries]") -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _OVERRIDABLE

    @classmethod
    def wrapped_type(cls: "Type[Overridable_DiameterSeries]") -> "_2216.DiameterSeries":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly

        Returns:
            _2216.DiameterSeries
        """
        return _2216.DiameterSeries

    @classmethod
    def implicit_type(cls: "Type[Overridable_DiameterSeries]") -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _2216.DiameterSeries.type_()

    @property
    def value(self: "Self") -> "_2216.DiameterSeries":
        """mastapy.bearings.bearing_designs.rolling.DiameterSeries

        Note:
            This property is readonly.
        """
        return None

    @property
    def overridden(self: "Self") -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        return None

    @property
    def override_value(self: "Self") -> "_2216.DiameterSeries":
        """mastapy.bearings.bearing_designs.rolling.DiameterSeries

        Note:
            This property is readonly.
        """
        return None

    @property
    def calculated_value(self: "Self") -> "_2216.DiameterSeries":
        """mastapy.bearings.bearing_designs.rolling.DiameterSeries

        Note:
            This property is readonly.
        """
        return None

==> mastapy-15.0.0b4-py3-none-any.whl: mastapy/_private/_internal/implicit/overridable/diameter_series.py <==
"""Implementations of 'Overridable' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal import mixins
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.bearings.bearing_designs.rolling import _2361

_OVERRIDABLE = python_net_import("SMT.MastaAPI.Utility.Property", "Overridable")

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="Overridable_DiameterSeries")


__docformat__ = "restructuredtext en"
__all__ = ("Overridable_DiameterSeries",)


class Overridable_DiameterSeries(mixins.OverridableMixin, Enum):
    """Overridable_DiameterSeries

    A specific implementation of 'Overridable' for 'DiameterSeries' types.
    """

    __qualname__ = "DiameterSeries"

    @classmethod
    def wrapper_type(cls: "Type[Overridable_DiameterSeries]") -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _OVERRIDABLE

    @classmethod
    def wrapped_type(cls: "Type[Overridable_DiameterSeries]") -> "_2361.DiameterSeries":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly

        Returns:
            _2361.DiameterSeries
        """
        return _2361.DiameterSeries

    @classmethod
    def implicit_type(cls: "Type[Overridable_DiameterSeries]") -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _2361.DiameterSeries.type_()

    @property
    @exception_bridge
    def value(self: "Self") -> "_2361.DiameterSeries":
        """mastapy.bearings.bearing_designs.rolling.DiameterSeries

        Note:
            This property is readonly.
        """
        return None

    @property
    @exception_bridge
    def overridden(self: "Self") -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        return None

    @property
    @exception_bridge
    def override_value(self: "Self") -> "_2361.DiameterSeries":
        """mastapy.bearings.bearing_designs.rolling.DiameterSeries

        Note:
            This property is readonly.
        """
        return None

    @property
    @exception_bridge
    def calculated_value(self: "Self") -> "_2361.DiameterSeries":
        """mastapy.bearings.bearing_designs.rolling.DiameterSeries

        Note:
            This property is readonly.
        """
        return None
